#
# spec file for package just
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_with     tests
Name:           just
Version:        1.40.0
Release:        1.1
Summary:        Commmand runner
License:        (Apache-2.0 OR MIT) AND Unicode-DFS-2016 AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (MIT OR Unlicense) AND Apache-2.0 AND BSD-3-Clause AND CC0-1.0 AND MIT AND CC0-1.0
Group:          Development/Tools/Building
URL:            https://github.com/casey/just
Source0:        https://github.com/casey/just/archive/refs/tags/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  bash-completion
BuildRequires:  cargo-packaging
BuildRequires:  fish
BuildRequires:  git-core
BuildRequires:  python3-base
BuildRequires:  zsh
BuildRequires:  zstd

%description
Just is a command runner. Although it shares
some similarities with "make", it is not a build
system.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%autosetup -a1

%build
%{cargo_build} --all-features
mkdir completions
./target/release/just --completions bash > completions/just.bash
./target/release/just --completions fish > completions/just.fish
./target/release/just --completions zsh > completions/just.zsh

%install
%{cargo_install} --all-features
install -Dm644 -T completions/%{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 -T completions/%{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish
install -Dm644 -T completions/%{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}

%if %{with tests}
%check
# we skip the tests, as they are super flakely
%{cargo_test} --all
%endif

%files
%license LICENSE
%doc *.md
%{_bindir}/%{name}

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Mon Mar 10 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.40.0:
  * Allow the target of aliases to be recipes in submodules
  * Make --list-submodules require --list
  * Star parameters may follow default parameters
  * Remove test! macro from readme
  * Sort enum variant, struct member, and trait members alphabetically
  * Add Zed extension to readme
  * Refactor error checking in choose function
  * Use Test struct instead of test! macro
  * Include unicode codepoint in unknown start of token error
  * Ignore broken pipe error from chooser
  * Guarantee that Namepaths are non-empty
  * Remove unnecessary binding modifiers
  * Document Vim and Neovim built-in syntax highlighting
  * Remove rust:just Repology badge
  * Clarify --list argument
  * Expand Windows path documentation
  * Fix readme typos
* Thu Jan 23 2025 Richard Rahl <rrahl0@opensuse.org>
- update to 1.39.0:
  * Add which() and require() for finding executables
  * Add no-exit-message Setting and [exit-message] attribute
  * Configure alias style in --list with --alias-style
  * Add regex mismatch conditional operator
  * Add read_to_string(path) function
  * Rename read_to_string() to read()
  * Keep [private] attribute when formatting assignments
  * Format if … else if … without superfluous braces
  * Fix error when lexing ! at end-of-file
  * Handle recipes in submodules in fish completion script
  * Add tests for require()
  * Evaluate concatenations and joins from left to right
  * Disable links to empty chapters in book
  * Clarify that trim_*_match functions take subtrings
  * Check attributes in parser instead of analyzer
  * Ignore I/O errors when writing changelog to stdout
  * Add quiet setting and fix typos in readme
  * Update readme to use env() instead of env_var*()
  * Document using || to provide default for empty environment variable
  * Refactor Line predicates
  * Fix typos in README.md
  * Add full example getting XDG user directory to readme
  * Document weird behavior of duplicate definitions in imports
  * Update readme to reflect actual behavior of user directory functions
  * Document running python recipes with uv
  * Sort functions alphabetically
  * Fix truncated bang operator error message
  * Include source path in dump JSON
  * Add attribute set
* Fri Dec 20 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Cleanup specfile
  * use archived tarball from upstream
  * remove cargo_config
- Update vendored dependencies
* Wed Dec 18 2024 Richard Rahl <rrahl0@opensuse.org>
- skip all tests, as for some reason, now other tests are flaky.
  so test have to be done now manually when packaging a newer version.
* Sat Dec 14 2024 Richard Rahl <rrahl0@opensuse.org>
- skip tests which are very flaky on most non x86_64 (even on x86_64,
  it sometimes flakes)
* Wed Dec 11 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.38.0:
  * Add [openbsd] recipe attribute
  * Add [working-directory] recipe attribute
  * Add --allow-missing to ignore missing recipe and submodule errors
  * Add snap package back to readme
  * Forbid duplicate non-repeatable attributes
  * Publish docs to GitHub pages on release only
  * Note lack of support for string interpolation
  * Embolden help text errors
  * Style help text
  * Add --request subcommand for testing
  * [bin/forbid] Improve error message if ripgrep is missing
  * Fix Rust 1.83 clippy warnings
  * Refactor JSON tests
  * Get Config from ExecutionContext instead of passing separately
  * Don't write justfiles unchanged by formatting
- switch to tar_scm, so we can actually offer the correct package-meta
* Wed Nov 20 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.37.0:
  * Add style() function
  * Terminal escape sequence constants
  * Add && and || operators
  * Make recipe doc attribute override comment
  * Don't export constants
  * Allow duplicate imports
  * Publish single SHA256SUM file with releases
  * Mark recipes with private attribute as private in JSON dump
  * Forbid invalid attributes on assignments
  * Add -g to rust-just install instructions
  * Change doc backtick color to cyan
  * Note that set shell is not used for [script] recipes
  * Replace derivative with derive-where
  * Highlight backticks in docs when listing recipes
  * Update setup-just version in README
  * Fix shell function example in readme
  * Update softprops/action-gh-release
  * Use justfile instead of mf on invalid examples in readme
  * Add advice on printing complex strings
  * Document using functions in variable assignments
  * Use prettier string comparison in tests
  * Note shell(…) as an alternative to backticks
  * Add Recipe::subsequents
  * Add subsequents to grammar
  * Document checking releases hashes
  * Show how to access positional arguments with powershell
  * Use -CommandWithArgs instead of -cwa
  * Document -cwa flag for PowerShell positional arguments
  * Use unwrap_or when creating relative path in loader
* Tue Oct  1 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.36.0:
  * Allow default values to use earlier recipe arguments
  * Add `--one` flag to forbid multiple recipes from being invoked
  * Allow including arbitrary characters in strings with `\u{…}`
  * Print recipe doc string when`--explain` flag  is passed
  * Use unwrap_or_default() when getting default color and verbosity
  * De-duplicate suggestion methods
  * Refactor analyzer
  * Use `console` codeblocks in readme
  * Add PyPI install instructions
  * Remove old recipes from project justfile
  * Fix clippy lints
- remove cargo_audit, as it's included in cargo_vendor
* Thu Aug 29 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.35.0:
  * Allow fallback with recipes in submodules
  * Allow [private] attribute on assignments
  * Generate .sha256sum files for release artifacts
  * Clarify that subsequent dependencies run immediately after recipe
  * Remove Config::run
  * Remove logging
  * Group commands under dedicated heading in --help output
* Fri Aug  2 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.34.0:
  * Make function paths relative to correct working directory
  * Keep multi-line shebangs together
* Wed Jul 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.33.0:
  * Use correct backtick and shell() expression working directory in submodules
  * Add working-directory setting
  * Allow [group] attribute on submodules
  * Allow empty [script] attribute and add set script-interpreter
  * Document which attributes apply to which items
  * Add missing productions
  * Fix Rust 1.80.0 warnings
  * Remove (no group) header before ungrouped recipes
  * Document script-interpreter setting
  * set dotenv-path does not override set dotenv-filename
* Thu Jul 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.32.0:
  * Add unstable [script(…)] attribute
  * Add [extension: 'EXT'] attribute to set shebang recipe script file extension
  * Suppress mod doc comment with empty [doc] attribute
  * Allow [doc] annotation on modules
* Tue Jul 16 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.31.0:
  * Stabilize modules
  * Allow mod path to be directory containing module source
  * Allow enabling unstable features with set unstable
  * Allow abbreviating functions ending in _directory to _dir
  * Lexiclean search directory so .. does not check the current directory
  * Print space before submodules in --list with groups
* Sun Jul  7 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.30.1:
  Fixes
  * Fix function argument count mismatch error message
- Update to version 1.30.0:
  Fixed
  * Allow comments after mod statements
  Changed
  * Allow unstable features with --summary
  * Don't analyze comments when ignore-comments is set
  * List recipes by group in group justfile order with just
  - -list --unsorted
  * List groups in source order with just --groups --unsorted
  Added
  * Avoid install and add 32-bit arm targets to install.sh
  * Give modules doc comments for --list
  * Add datetime() and datetime_utc() functions
  * Allow setting more command-line options with environment
    variables
  Library
  * Don't exit process in run() on argument parse error
  * Allow passing command-line arguments into run()
  * Ignore env_logger initialization errors
  Misc
  * Tweak readme
  * Add development guide to readme
  * Add shell-expanded string syntax to grammar
  * Add recipe for testing bash completion script
  * Fix use of justfile_directory() in readme
  * Use default values for --list-heading and --list-prefix
  * Use clap::ValueParser
  * Document module doc comments in readme
  * Use -and instead of && in PowerShell completion script
  * Fix readme formatting
  * Link to justfiles on GitHub in readme
  * Link to modules when first introduced in readme
  * Update softprops/action-gh-release
  * Document remote justfile workaround
  * Document library interface
  * Remove dependency on cradle
  * Add note to readme about quoting paths on Windows
  * Add missing changelog credits
  * Credit myself in changelog
* Mon Jun 17 2024 Soc Virnyl Estela <obs@uncomfyhalomacro.pl>
- Various shell completion packages are needed for tests
  * fish, bash, zsh
- Service file update
  * replace glob to avoid vendoring the vendored tarball although likely
    it does not happen but just in case.
  * set filter to true
- Source0 tarball points to github releases/tags
- Remove patch ignore-test.patch.
- Add python for tests
* Sun Jun 16 2024 rrahl0@disroot.org
- Update to version 1.29.1:
  * Release 1.29.1 (#2159)
  * Fix unexport syntax conflicts (#2158)
  * Release 1.29.0 (#2155)
  * Improve argument parsing and error handling for submodules (#2154)
  * Document shell expanded string defaults (#2153)
  * Load environment file from dotenv-path relative to working directory (#2152)
  * Add [positional-arguments] attribute (#2151)
  * Test bare bash path in shebang on windows (#2144)
  * Use `--justfile` in Fish shell completions (#2148)
  * Test shell not found error messages (#2145)
  * Add `is_dependency()` function (#2139)
  * Fix `fzf` chooser preview with space-separated module paths (#2141)
  * Allow printing nu completion script with `just --completions nushell` (#2140)
  * Add `[ATTRIBUTE: VALUE]` shorthand (#2136)
  * Refactor evaluator (#2138)
  * Allow unexporting environment variables (#2098)
* Thu Jun  6 2024 rrahl0@disroot.org
- Update to version 1.28.0:
  * Fix man page generation in release workflow (#2132)
  * Release 1.28.0 (#2131)
  * Don't check in manpage (#2130)
  * Document default shell (#2129)
  * Write shebang recipes to $XDG_RUNTIME_DIR (#2128)
  * Remove duplicate section in Chinese readme (#2127)
  * Update Chinese readme (#2124)
  * Fix typo in readme (#2122)
  * Don't check in auto-generated completion scripts (#2120)
  * Add `set dotenv-required` to require an environment file (#2116)
  * Allow listing recipes in submodules with `--list-submodules` (#2113)
  * Use space-separated recipe paths in `--choose` (#2115)
  * Don't display submodule recipes in `--list` (#2112)
  * Show recipes in submodules with `--show RECIPE::PATH` (#2111)
  * Add `--timestamp-format` (#2106)
  * Allow listing submodule recipes with `--list PATH` (#2108)
  * Print recipe command timestamps with `--timestamps` (#2084)
  * Add `module_file()` and `module_directory()` functions (#2105)
  * Fix bash completion for aliases (#2104)
  * Document when dependencies run in readme (#2103)
  * Build aarch64-pc-windows-msvc release binaries (#2100)
  * Clarify that `dotenv-path`-given env file is required (#2099)
  * Print multi-line doc comments before recipe in `--list` (#2090)
  * List unsorted imported recipes by import depth and offset (#2092)
  * Update README.md (#2091)
* Sat May 25 2024 rrahl0@disroot.org
- Update to version 1.27.0:
  * Release 1.27.0 (#2089)
  * Add `[doc]` attribute to set and suppress documentation comments (#2050)
  * Add source_file() and source_directory() functions (#2088)
  * List modules in source order with `--unsorted` (#2085)
  * Add recipe groups (#1842)
  * Forbid whitespace in shell-expanded string prefixes (#2083)
  * Add Debian and Ubuntu install instructions to readme (#2072)
  * Remove snap installation instructions from readme (#2070)
  * Show submodule recipes in --choose (#2069)
  * Fallback to wget in install script if curl isn't available(#1913)
  * Use cache dir for temporary files (#2067)
  * Use std::io::IsTerminal instead of atty crate (#2066)
  * Improve `shell()` documentation (#2060)
  * Add bash completion for snap (#2058)
  * Allow multiple imports of the same file in different modules (#2065)
  * Fix submodule recipe listing indentation (#2063)
  * Refactor list subcommand (#2062)
  * Pass command as first argument to `shell` (#2061)
  * Add shell() function for running external commands (#2047)
  * Allow shell expanded strings in mod and import paths (#2059)
  * Add `--global-justfile` flag (#1846)
  * Run imported recipes in root justfile with correct working directory (#2056)
  * Add shell-expanded strings (#2055)
  * Add `encode_uri_component` function (#2052)
  * Add `choose` function for generating random strings (#2049)
  * Add predefined constants (#2054)
  * Document working directory (#2053)
  * Replace FunctionContext with Evaluator (#2048)
  * Allow setting some command-line options with environment variables (#2044)
  * Add prepend() function (#2045)
  * Add append() function (#2046)
  * Add --man subcommand (#2041)
  * Make `dotenv-path` relative to working directory (#2040)
  * Update clap to version 4 (#1924)
  * Cleanup (#2026)
  * Increase --list maximum alignable width from 30 to 50 (#2039)
  * Document using `env -S` (#2038)
  * Update line continuation documentation (#1998)
  * Add `assert` expression (#1845)
  * Add 'allow-duplicate-variables' setting (#1922)
  * Add example using GNU parallel to run tasks in concurrently (#1915)
  * Placate clippy: use `clone_into` (#2037)
  * Use --command-color when printing shebang recipe commands (#1911)
  * Document how to use watchexec to re-run recipes when files change (#2036)
  * Fix output `\r\n` stripping (#2035)
  * Update VS Code extensions in readme (#2034)
  * Add rust:just repology package table to readme (#2032)
- add ignore-test.patch, as the backtick test fails only on OBS
* Tue May 14 2024 rrahl0@disroot.org
- Update to version 1.26.0:
  * Update dependencies
  * Clarify that janus operates on public justfiles only (#2021)
  * Fix Error::TmpdirIo error message (#1987)
  * Add --no-aliases to hide aliases in --list (#1961)
  * Add -E as alias for --dotenv-path (#1910)
  * Rename `delete` example recipe to `delete-all` (#1966)
- enable upstream tests
* Mon Mar 18 2024 rrahl0@proton.me
- Update to version 1.25.2:
  * Unpin ctrlc
- Update to version 1.25.1:
  * Pin ctrlc to version 3.1.1
  * Fix AArch64 release build error
- Update to version 1.25.0:
  * Add `blake3` and `blake3_file` functions
  * Fix readme typo
  * Use unwrap_or_default
  * Set codegen-units to 1 reduce release binary size
  * Fix install.sh shellcheck warnings
  * Document openSUSE package
- Update to version 1.24.0:
  * Support recipe paths containing `::` in Bash completion script
  * Add function to canonicalize paths
  * Use unlikely-to-be-set variable name in env tests
  * Skip write_error test if running as root
  * Convert run_shebang into integration test
  * Fix typos found by codespell
  * Fix install script
- simplify spec and _service file
- use more macros
* Thu Jan 18 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.23.0:
  * Allow setting custom confirm prompt
  * Add `set quiet` and `[no-quiet]`
  * Add `just_pid` function
  * Include completion scripts in releases
  * Run imports in working directory of importer
  * Tweak readme table formatting
  * Add functions to return XDG base directories
  * Don't abbreviate just in README
  * Add `--no-deps` to skip running recipe dependencies
  * Ignore [private] recipes in just --list
  * Add a dash to tempdir prefix
  * Don't conflate recipes with the same name in different modules
  * Clarify that UUID is version 4
  * Make sigil stripping from recipe lines less incomprehensible
  * Refactor invalid path argument check
  * Recipes can be invoked with path syntax
  * Move table of contents pointer to right
  * Add `--format` and `--initialize` as aliases for `--fmt` and `--init`
  * Use box-drawing characters in error messages
  * Optional modules and imports
  * Use Self
  * Print submodule recipes in --summary
  * Expand tilde in import and module paths
  * Document import override behavior
  * Override imported recipes
  * Document submodule working directory
  * Run recipes with working directory set to submodule directory
  * Allow mod statements with path to source file
* Thu Dec 28 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.19.0:
  * Add modules
* Mon Dec 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.18.1:
  * Display a descriptive error for `!include` directives
  * Tweak readme
  * Stabilize `!include path` as `import 'path'`
* Wed Dec 20 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.17.0:
  * Pass justfile path to default chooser
  * Pass `--unstable` and `--color always` to default chooser
  * Update Gentoo package repository
  * Fix readme header level
  * Document line continuations
  * List included recipes in load order
  * Rename Justfile::first → Justfile::default
  * Don't default to included recipes
* Sat Dec  2 2023 xtexchooser@duck.com
- Update to version 1.16.0:
  * Fix readme typo
  * Fix Fish completion script
  * Add ARMv6 release target
  * Add `semver_matches` function
  * Clean up error display
  * Misc fixes
  * Fix readme build badge
  * Add `dotenv-filename` and `dotenv-path` settings
  * Fix set tempdir grammar
  * Add version to attributes
  * Allow setting echoed recipe line color
  * Update README.md
* Wed Oct 25 2023 Soc Virnyl Estela <contact@uncomfyhalomacro.pl>
- Update to version 1.15.0:
  * Add Nushell completion script
  * Update Indentation Documentation
  * Allow unstable features to be enabled with environment variable
  * Fix triple-quoted string example in readme
  * README fix: the -d in `mktemp -d` is required to created folders.
  * Placate clippy
  * Add num_cpus() function
  * Document Windows Package Manager install instructions
  * Test unpaired escaped carriage return error
  * Allow escaping newlines
  * Stabilize JSON dump format
  * Avoid grep aliases in bash completions
  * Clarify [unix] attribute in readme
  * Add env() function
  * Add descriptions to fish recipe completions
  * Allow selecting multiple recipes with default chooser
  * Add better documentation for --dump and --fmt
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Revert update of vendored dependencies.
* Sat Sep  2 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update vendored dependencies
- Update source cargo_config
* Sun Aug 13 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Replace obsoleted `disabled` option with `manual`
* Sat Jun  3 2023 socvirnyl.estela@gmail.com
- Update to version 1.14.0:
  * Ignore clippy::let_underscore_untyped
  * Use `just --show` in default chooser
  * Update README to reflect new attribute syntax
  * Allow multiple attributes on one line
  * Analyze and Compiler tweaks
  * Downgrade to TLS 1.2 in install script
* Sun Mar  5 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for just 1.13.0
